@@ -36,7 +36,7 @@
 
 #include "asterisk.h"
 
-ASTERISK_FILE_VERSION(__FILE__, "$Revision: 68070 $")
+ASTERISK_FILE_VERSION(__FILE__, "$Revision: 73052 $")
 
 #include "asterisk/lock.h"
 #include "asterisk/file.h"
@@ -1574,7 +1574,7 @@ static int dial_exec_full(struct ast_channel *chan, void *data, struct ast_flags
 				time_t now;
 
 				time(&now);
-				chan->whentohangup = now + calldurationlimit;
+				peer->whentohangup = now + calldurationlimit;
 			}
 			if (!ast_strlen_zero(dtmfcalled)) { 
 				if (option_verbose > 2)
@@ -1706,7 +1706,7 @@ static int retrydial_exec(struct ast_channel *chan, void *data)
 	if ((dialdata = strchr(announce, '|'))) {
 		*dialdata = '\0';
 		dialdata++;
-		if ((sleep = atoi(dialdata))) {
+		if (sscanf(dialdata, "%d", &sleep) == 1) {
 			sleep *= 1000;
 		} else {
 			ast_log(LOG_ERROR, "%s requires the numerical argument <sleep>\n",rapp);
@@ -1716,7 +1716,7 @@ static int retrydial_exec(struct ast_channel *chan, void *data)
 		if ((dialdata = strchr(dialdata, '|'))) {
 			*dialdata = '\0';
 			dialdata++;
-			if (!(loops = atoi(dialdata))) {
+			if (sscanf(dialdata, "%d", &loops) != 1) {
 				ast_log(LOG_ERROR, "%s requires the numerical argument <loops>\n",rapp);
 				LOCAL_USER_REMOVE(u);
 				return -1;
