@@ -33,7 +33,7 @@
 
 #include "asterisk.h"
 
-ASTERISK_FILE_VERSION(__FILE__, "$Revision: 52716 $")
+ASTERISK_FILE_VERSION(__FILE__, "$Revision: 72378 $")
 
 #include "asterisk/file.h"
 #include "asterisk/logger.h"
@@ -68,8 +68,8 @@ static const char *desc = ""
 " W(<x>) - Adjust the both heard and spoken volumes by a factor of <x>\n"
 "         (range -4 to 4)\n\n"	
 "<command> will be executed when the recording is over\n"
-"Any strings matching ^{X} will be unescaped to ${X} and \n"
-"all variables will be evaluated at that time.\n"
+"Any strings matching ^{X} will be unescaped to ${X}.\n"
+"All variables will be evaluated at the time MixMonitor is called.\n"
 "The variable MIXMONITOR_FILENAME will contain the filename used to record.\n"
 "";
 
