@@ -37,7 +37,7 @@
 
 #include "asterisk.h"
 
-ASTERISK_FILE_VERSION(__FILE__, "$Revision: 60846 $")
+ASTERISK_FILE_VERSION(__FILE__, "$Revision: 73318 $")
 
 #include "asterisk/lock.h"
 #include "asterisk/channel.h"
@@ -391,10 +391,10 @@ static int local_call(struct ast_channel *ast, char *dest, int timeout)
 		}
 	}
 
-	p->launchedpbx = 1;
-
 	/* Start switch on sub channel */
-	res = ast_pbx_start(p->chan);
+	if (!(res = ast_pbx_start(p->chan)))
+		p->launchedpbx = 1;
+
 	ast_mutex_unlock(&p->lock);
 	return res;
 }
