@@ -34,6 +34,9 @@
 #include <arpa/inet.h>
 #include <fcntl.h>
 #include <sys/ioctl.h>
+#ifdef HAVE_LINUX_COMPILER_H
+#include <linux/compiler.h>
+#endif
 #include <linux/telephony.h>
 /* Still use some IXJ specific stuff */
 #include <linux/version.h>
@@ -41,7 +44,7 @@
 
 #include "asterisk.h"
 
-ASTERISK_FILE_VERSION(__FILE__, "$Revision: 61777 $")
+ASTERISK_FILE_VERSION(__FILE__, "$Revision: 74587 $")
 
 #include "asterisk/lock.h"
 #include "asterisk/channel.h"
