@@ -215,7 +215,11 @@ union facility {
 struct misdn_bchannel {
 	struct send_lock *send_lock;
 
+	int dummy;
+
 	int nt;
+	int pri;
+
 	int port;
 	/** init stuff **/
 	int b_stid;
@@ -362,16 +366,8 @@ struct misdn_bchannel {
 	int ec_deftaps;
 	int ec_training;
 #endif
-
-#ifdef WITH_BEROEC
-	beroec_t *ec;
-	int bnec_tail;
-	int bnec_ah;
-	int bnec_nlp;
-	int bnec_td;
-	int bnec_adapt;
-	int bnec_zero;
-#endif
+	
+	int channel_found;
 	
 	int orig;
 
@@ -478,6 +474,7 @@ void misdn_lib_reinit_nt_stack(int port);
 char *bc_state2str(enum bchannel_state state);
 void bc_state_change(struct misdn_bchannel *bc, enum bchannel_state state);
 
+void misdn_dump_chanlist(void);
 
 
 #endif
