@@ -41,7 +41,7 @@
 
 #include "asterisk.h"
 
-ASTERISK_FILE_VERSION(__FILE__, "$Revision: 53117 $")
+ASTERISK_FILE_VERSION(__FILE__, "$Revision: 69469 $")
 
 #include "asterisk/config.h"
 #include "asterisk/cli.h"
@@ -409,7 +409,6 @@ static int process_text_line(struct ast_config *cfg, struct ast_category **cat,
 				} else if (!strcasecmp(cur, "+")) {
 					*cat = category_get(cfg, catname, 1);
 					if (!*cat) {
-						ast_config_destroy(cfg);
 						if (newcat)
 							ast_category_destroy(newcat);
 						ast_log(LOG_WARNING, "Category addition requested, but category '%s' does not exist, line %d of %s\n", catname, lineno, configfile);
@@ -662,7 +661,7 @@ static struct ast_config *config_text_file_load(const char *database, const char
 		fclose(f);		
 	} while(0);
 	if (comment) {
-		ast_log(LOG_WARNING,"Unterminated comment detected beginning on line %d\n", nest[comment]);
+		ast_log(LOG_WARNING,"Unterminated comment detected beginning on line %d\n", nest[comment - 1]);
 	}
 #ifdef AST_INCLUDE_GLOB
 					if (!cfg)
@@ -966,6 +965,8 @@ struct ast_config *ast_config_internal_load(const char *filename, struct ast_con
 
 	if (result)
 		result->include_level--;
+	else
+		cfg->include_level--;
 
 	return result;
 }
