@@ -1,22 +1,29 @@
 /*
- * Asterisk -- A telephony toolkit for Linux.
+ * Asterisk -- An open source telephony toolkit.
  *
- * ADSI Support (built upon Caller*ID) 
- * 
- * Copyright (C) 1999, Mark Spencer
+ * Copyright (C) 1999 - 2005, Digium, Inc.
  *
- * Mark Spencer <markster@linux-support.net>
+ * Mark Spencer <markster@digium.com>
+ *
+ * See http://www.asterisk.org for more information about
+ * the Asterisk project. Please do not directly contact
+ * any of the maintainers of this project for assistance;
+ * the project provides a web site, mailing lists and IRC
+ * channels for your use.
  *
  * This program is free software, distributed under the terms of
- * the GNU General Public License.
- *
- * Includes code and algorithms from the Zapata library.
- *
+ * the GNU General Public License Version 2. See the LICENSE file
+ * at the top of the source tree.
  */
 
-#ifndef _ADSI_H
-#define _ADSI_H
-#include <asterisk/callerid.h>
+/*! \file
+ * \brief ADSI Support (built upon Caller*ID) 
+ */
+
+#ifndef _ASTERISK_ADSI_H
+#define _ASTERISK_ADSI_H
+
+#include "asterisk/callerid.h"
 
 /* ADSI Message types */
 #define ADSI_MSG_DISPLAY	132
@@ -110,8 +117,8 @@
 #define ADSI_DIR_FROM_LEFT (0)
 #define ADSI_DIR_FROM_RIGHT (1)
 
-//! Perform Asterisk ADSI initialization (for channel drivers that want
-//   to support ADSI when the handset is first lifted) */
+/*! Perform Asterisk ADSI initialization (for channel drivers that want */
+/*    to support ADSI when the handset is first lifted) */ 
 /*! 
  * \param chan Channel to initialize for ADSI (if supported)
  * 
@@ -120,13 +127,13 @@
  */
 extern int adsi_channel_init(struct ast_channel *chan);
 
-extern int adsi_begin_download(struct ast_channel *chan, char *service, char *fdn, char *sec, int version);
+extern int adsi_begin_download(struct ast_channel *chan, char *service, unsigned char *fdn, unsigned char *sec, int version);
 
 extern int adsi_end_download(struct ast_channel *chan);
 
-//! Restore ADSI initialization (for applications that play with ADSI
-//  and want to restore it to normal.  If you touch "INFO" then you
-//  have to use the adsi_channel_init again instead.
+/*! Restore ADSI initialization (for applications that play with ADSI */
+/*   and want to restore it to normal.  If you touch "INFO" then you */
+/*   have to use the adsi_channel_init again instead. */
 /*!
  * \param chan Channel to restore
  * 
@@ -135,7 +142,7 @@ extern int adsi_end_download(struct ast_channel *chan);
  */
 extern int adsi_channel_restore(struct ast_channel *chan);
 
-//! Display some stuff on the screen
+/*! Display some stuff on the screen */
 /*!
  * \param chan Channel to display on
  * \param lines NULL-terminated list of things to print (no more than 4 recommended)
@@ -147,8 +154,8 @@ extern int adsi_channel_restore(struct ast_channel *chan);
  */
 extern int adsi_print(struct ast_channel *chan, char **lines, int *align, int voice);
 
-//! Check if scripts for a given app are already loaded.  Version may be -1
-//  if any version is okay, or 0-255 for a specific version.
+/*! Check if scripts for a given app are already loaded.  Version may be -1 */
+/*   if any version is okay, or 0-255 for a specific version. */
 /*!
  * \param chan Channel to test for loaded app
  * \param app Four character app name (must be unique to your application)
@@ -164,8 +171,8 @@ extern int adsi_unload_session(struct ast_channel *chan);
 /* ADSI Layer 2 transmission functions */
 extern int adsi_transmit_messages(struct ast_channel *chan, unsigned char **msg, int *msglen, int *msgtype);
 extern int adsi_transmit_message(struct ast_channel *chan, unsigned char *msg, int msglen, int msgtype);
-
-//! Read some encoded DTMF data.  
+extern int adsi_transmit_message_full(struct ast_channel *chan, unsigned char *msg, int msglen, int msgtype, int dowait);
+/*! Read some encoded DTMF data.   */
 /*!
  * Returns number of bytes received
  */
@@ -173,7 +180,7 @@ extern int adsi_read_encoded_dtmf(struct ast_channel *chan, unsigned char *buf,
 
 /* ADSI Layer 3 creation functions */
 
-//! Connects an ADSI Display Session */
+/*! Connects an ADSI Display Session */ 
 /*!
  * \param buf Character buffer to create parameter in (must have at least 256 free)
  * \param fdn Optional 4 byte Feature Download Number (for loading soft keys)
@@ -185,14 +192,14 @@ extern int adsi_read_encoded_dtmf(struct ast_channel *chan, unsigned char *buf,
 
 extern int adsi_connect_session(unsigned char *buf, unsigned char *fdn, int ver);
 
-//! Build Query CPE ID of equipment */
+/*! Build Query CPE ID of equipment */ 
 /*!
  *  Returns number of bytes added to message
  */
 extern int adsi_query_cpeid(unsigned char *buf);
 extern int adsi_query_cpeinfo(unsigned char *buf);
 
-//! Get CPE ID from an attached ADSI compatible CPE.
+/*! Get CPE ID from an attached ADSI compatible CPE. */
 /*!
  * Returns 1 on success, storing 4 bytes of CPE ID at buf
  * or -1 on hangup, or 0 if there was no hangup but it failed to find the
@@ -202,10 +209,10 @@ extern int adsi_get_cpeid(struct ast_channel *chan, unsigned char *cpeid, int vo
 
 extern int adsi_get_cpeinfo(struct ast_channel *chan, int *width, int *height, int *buttons, int voice);
 
-//! Begin an ADSI script download */
+/*! Begin an ADSI script download */ 
 /*!
  * \param buf Character buffer to create parameter in (must have at least 256 free)
- * \param service, a 1-18 byte name of the feature
+ * \param service a 1-18 byte name of the feature
  * \param fdn 4 byte Feature Download Number (for loading soft keys)
  * \param sec 4 byte vendor security code
  * \param ver version number (0-255, or -1 to omit)
@@ -214,9 +221,9 @@ extern int adsi_get_cpeinfo(struct ast_channel *chan, int *width, int *height, i
  *
  */
 
-extern int adsi_download_connect(unsigned char *buf, unsigned char *service, unsigned char *fdn, unsigned char *sec, int ver);
+extern int adsi_download_connect(unsigned char *buf, char *service, unsigned char *fdn, unsigned char *sec, int ver);
 
-//! Disconnects a running session
+/*! Disconnects a running session */
 /*!
  * \param buf Character buffer to create parameter in (must have at least 256 free)
  *
@@ -225,7 +232,7 @@ extern int adsi_download_connect(unsigned char *buf, unsigned char *service, uns
  */
 extern int adsi_disconnect_session(unsigned char *buf);
 
-//! Disconnects (and hopefully saves) a downloaded script
+/*! Disconnects (and hopefully saves) a downloaded script */
 /*!
  * \param buf Character buffer to create parameter in (must have at least 256 free)
  *
@@ -234,7 +241,7 @@ extern int adsi_disconnect_session(unsigned char *buf);
  */
 extern int adsi_download_disconnect(unsigned char *buf);
 
-//! Puts CPE in data mode...
+/*! Puts CPE in data mode... */
 /*!
  * \param buf Character buffer to create parameter in (must have at least 256 free)
  *
@@ -245,7 +252,7 @@ extern int adsi_data_mode(unsigned char *buf);
 extern int adsi_clear_soft_keys(unsigned char *buf);
 extern int adsi_clear_screen(unsigned char *buf);
 
-//! Puts CPE in voice mode...
+/*! Puts CPE in voice mode... */
 /*!
  * \param buf Character buffer to create parameter in (must have at least 256 free)
  * \param when (a time in seconds) to make the switch
@@ -255,14 +262,14 @@ extern int adsi_clear_screen(unsigned char *buf);
  */
 extern int adsi_voice_mode(unsigned char *buf, int when);
 
-//! Returns non-zero if Channel does or might support ADSI
+/*! Returns non-zero if Channel does or might support ADSI */
 /*!
  * \param chan Channel to check
  *
  */
 extern int adsi_available(struct ast_channel *chan);
 
-//! Loads a line of info into the display */
+/*! Loads a line of info into the display */ 
 /*!
  * \param buf Character buffer to create parameter in (must have at least 256 free)
  * \param page Page to load (ADSI_COMM_PAGE or ADSI_INFO_PAGE)
@@ -276,9 +283,9 @@ extern int adsi_available(struct ast_channel *chan);
  *
  */
 
-extern int adsi_display(unsigned char *buf, int page, int line, int just, int wrap, unsigned char *col1, unsigned char *col2);
+extern int adsi_display(unsigned char *buf, int page, int line, int just, int wrap, char *col1, char *col2);
 
-//! Sets the current line and page */
+/*! Sets the current line and page */ 
 /*!
  * \param buf Character buffer to create parameter in (must have at least 256 free)
  * \param page Which page (ADSI_COMM_PAGE or ADSI_INFO_PAGE)
@@ -290,7 +297,7 @@ extern int adsi_display(unsigned char *buf, int page, int line, int just, int wr
 
 extern int adsi_set_line(unsigned char *buf, int page, int line);
 
-//! Creates "load soft key" parameters
+/*! Creates "load soft key" parameters */
 /*! 
  * \param buf Character buffer to create parameter in (must have at least 256 free)
  * \param key Key code from 2 to 33, for which key we are loading
@@ -302,9 +309,9 @@ extern int adsi_set_line(unsigned char *buf, int page, int line);
  * Returns number of bytes added to buffer or -1 on error.
  *
  */
-extern int adsi_load_soft_key(unsigned char *buf, int key, unsigned char *llabel, unsigned char *slabel, unsigned char *ret, int data);
+extern int adsi_load_soft_key(unsigned char *buf, int key, char *llabel, char *slabel, char *ret, int data);
 
-//! Set which soft keys should be displayed
+/*! Set which soft keys should be displayed */
 /*!
  * \param buf Character buffer to create parameter in (must have at least 256 free)
  * \param keys Array of 8 unsigned chars with the key numbers, may be OR'd with ADSI_KEY_HILITE
@@ -315,7 +322,7 @@ extern int adsi_load_soft_key(unsigned char *buf, int key, unsigned char *llabel
  */
 extern int adsi_set_keys(unsigned char *buf, unsigned char *keys);
 
-//! Set input information
+/*! Set input information */
 /*!
  * \param buf Character buffer to create parameter in (must have at least 256 free)
  * \param page Which page to input on (ADSI_COMM_PAGE or ADSI_INFO_PAGE)
@@ -329,7 +336,7 @@ extern int adsi_set_keys(unsigned char *buf, unsigned char *keys);
  */
 extern int adsi_input_control(unsigned char *buf, int page, int line, int display, int format, int just);
 
-//! Set input format
+/*! Set input format */
 /*!
  * \param buf Character buffer to create parameter in (must have at least 256 free)
  * \param num Which format we are setting
@@ -341,5 +348,6 @@ extern int adsi_input_control(unsigned char *buf, int page, int line, int displa
  * Returns number of bytes added to buffer or -1 on error.
  *
  */
-extern int adsi_input_format(unsigned char *buf, int num, int dir, int wrap, unsigned char *format1, unsigned char *format2);
-#endif
+extern int adsi_input_format(unsigned char *buf, int num, int dir, int wrap, char *format1, char *format2);
+
+#endif /* _ASTERISK_ADSI_H */
