@@ -1,19 +1,29 @@
 /*
- * Asterisk -- A telephony toolkit for Linux.
+ * Asterisk -- An open source telephony toolkit.
  *
- * OSP support
- * 
- * Copyright (C) 1999, Mark Spencer
+ * Copyright (C) 1999 - 2005, Digium, Inc.
  *
- * Mark Spencer <markster@linux-support.net>
+ * Mark Spencer <markster@digium.com>
+ *
+ * See http://www.asterisk.org for more information about
+ * the Asterisk project. Please do not directly contact
+ * any of the maintainers of this project for assistance;
+ * the project provides a web site, mailing lists and IRC
+ * channels for your use.
  *
  * This program is free software, distributed under the terms of
- * the GNU General Public License
+ * the GNU General Public License Version 2. See the LICENSE file
+ * at the top of the source tree.
+ */
+
+/*! \file
+ * \brief OSP support (Open Settlement Protocol)
  */
 
 #ifndef _ASTERISK_OSP_H
 #define _ASTERISK_OSP_H
-#include <asterisk/channel.h>
+
+#include "asterisk/channel.h"
 #include <netinet/in.h>
 #include <time.h>
 
@@ -35,4 +45,4 @@ int ast_osp_terminate(int handle, int cause, time_t start, time_t duration);
 
 int ast_osp_validate(char *provider, char *token, int *handle, unsigned int *timeout, char *callerid, struct in_addr addr, char *extension);
 
-#endif
+#endif /* _ASTERISK_OSP_H */
