@@ -32,7 +32,7 @@
 
 #include "asterisk.h"
 
-ASTERISK_FILE_VERSION(__FILE__, "$Revision: 56850 $")
+ASTERISK_FILE_VERSION(__FILE__, "$Revision: 72267 $")
 
 #include "asterisk/pbx.h"
 #include "asterisk/config.h"
@@ -1678,6 +1678,8 @@ static int pbx_load_module(void)
 							pri = strsep(&stringp, ",");
 							if (!pri)
 								pri="";
+							pri = ast_skip_blanks(pri);
+							pri = ast_trim_blanks(pri);
 							label = strchr(pri, '(');
 							if (label) {
 								*label = '\0';
