@@ -41,7 +41,7 @@
 
 #include "asterisk.h"
 
-ASTERISK_FILE_VERSION(__FILE__, "$Revision: 54771 $")
+ASTERISK_FILE_VERSION(__FILE__, "$Revision: 71656 $")
 
 #include "asterisk/file.h"
 #include "asterisk/logger.h"
@@ -569,14 +569,7 @@ static int handle_streamfile(struct ast_channel *chan, AGI *agi, int argc, char
 	max_length = ast_tellstream(fs);
 	ast_seekstream(fs, sample_offset, SEEK_SET);
 	res = ast_applystream(chan, fs);
-	res = ast_playstream(fs);
-	if (res) {
-		fdprintf(agi->fd, "200 result=%d endpos=%ld\n", res, sample_offset);
-		if (res >= 0)
-			return RESULT_SHOWUSAGE;
-		else
-			return RESULT_FAILURE;
-	}
+	ast_playstream(fs);
 	res = ast_waitstream_full(chan, argv[3], agi->audio, agi->ctrl);
 	/* this is to check for if ast_waitstream closed the stream, we probably are at
 	 * the end of the stream, return that amount, else check for the amount */
@@ -629,14 +622,7 @@ static int handle_getoption(struct ast_channel *chan, AGI *agi, int argc, char *
         max_length = ast_tellstream(fs);
         ast_seekstream(fs, sample_offset, SEEK_SET);
         res = ast_applystream(chan, fs);
-        res = ast_playstream(fs);
-        if (res) {
-                fdprintf(agi->fd, "200 result=%d endpos=%ld\n", res, sample_offset);
-                if (res >= 0)
-                        return RESULT_SHOWUSAGE;
-                else
-                        return RESULT_FAILURE;
-        }
+        ast_playstream(fs);
         res = ast_waitstream_full(chan, argv[3], agi->audio, agi->ctrl);
         /* this is to check for if ast_waitstream closed the stream, we probably are at
          * the end of the stream, return that amount, else check for the amount */
@@ -1117,7 +1103,7 @@ static int handle_exec(struct ast_channel *chan, AGI *agi, int argc, char **argv
 	}
 	fdprintf(agi->fd, "200 result=%d\n", res);
 
-	return res;
+	return res >= 0 ? RESULT_SUCCESS : RESULT_FAILURE;
 }
 
 static int handle_setcallerid(struct ast_channel *chan, AGI *agi, int argc, char **argv)
