@@ -51,7 +51,7 @@
 
 #include "asterisk.h"
 
-ASTERISK_FILE_VERSION(__FILE__, "$Revision: 53084 $")
+ASTERISK_FILE_VERSION(__FILE__, "$Revision: 75107 $")
 
 #include "asterisk/lock.h"
 #include "asterisk/file.h"
@@ -627,7 +627,7 @@ static int moh4_exec(struct ast_channel *chan, void *data)
 	return 0;
 }
 
-static struct mohclass *get_mohbyname(char *name)
+static struct mohclass *get_mohbyname(char *name, int warn)
 {
 	struct mohclass *moh;
 	moh = mohclasses;
@@ -636,6 +636,8 @@ static struct mohclass *get_mohbyname(char *name)
 			return moh;
 		moh = moh->next;
 	}
+	if (warn)
+		ast_log(LOG_WARNING, "Music on Hold class '%s' not found\n", name);
 	return NULL;
 }
 
@@ -658,8 +660,10 @@ static struct mohdata *mohalloc(struct mohclass *cl)
 	flags = fcntl(moh->pipe[1], F_GETFL);
 	fcntl(moh->pipe[1], F_SETFL, flags | O_NONBLOCK);
 	moh->parent = cl;
+	ast_mutex_lock(&moh_lock);
 	moh->next = cl->members;
 	cl->members = moh;
+	ast_mutex_unlock(&moh_lock);
 	return moh;
 }
 
@@ -832,7 +836,7 @@ static int moh_register(struct mohclass *moh, int reload)
 	int x;
 #endif
 	ast_mutex_lock(&moh_lock);
-	if (get_mohbyname(moh->name)) {
+	if (get_mohbyname(moh->name, 0)) {
 		if (reload) {
 			ast_log(LOG_DEBUG, "Music on Hold class '%s' left alone from initial load.\n", moh->name);
 		} else {
@@ -908,20 +912,19 @@ static void local_ast_moh_cleanup(struct ast_channel *chan)
 
 static int local_ast_moh_start(struct ast_channel *chan, char *class)
 {
-	struct mohclass *mohclass;
+	struct mohclass *mohclass = NULL;
 
-	if (ast_strlen_zero(class))
-		class = chan->musicclass;
-	if (ast_strlen_zero(class))
-		class = "default";
 	ast_mutex_lock(&moh_lock);
-	mohclass = get_mohbyname(class);
+	if (!ast_strlen_zero(class))
+		mohclass = get_mohbyname(class, 1);
+	if (!mohclass && !ast_strlen_zero(chan->musicclass))
+		mohclass = get_mohbyname(chan->musicclass, 1);
+	if (!mohclass)
+		mohclass = get_mohbyname("default", 1);
 	ast_mutex_unlock(&moh_lock);
 
-	if (!mohclass) {
-		ast_log(LOG_WARNING, "No class: %s\n", (char *)class);
+	if (!mohclass)
 		return -1;
-	}
 
 	ast_set_flag(chan, AST_FLAG_MOH);
 	if (mohclass->total_files) {
@@ -1045,11 +1048,11 @@ static int load_moh_classes(int reload)
 			args = strchr(data, ',');
 			if (args)
 				*args++ = '\0';
-			if (!(get_mohbyname(var->name))) {
+			if (!(get_mohbyname(var->name, 0))) {
 				class = moh_class_malloc();
 				if (!class) {
 					ast_log(LOG_WARNING, "Out of memory!\n");
-					return numclasses;
+					break;
 				}
 				
 				ast_copy_string(class->name, var->name, sizeof(class->name));
@@ -1070,14 +1073,14 @@ static int load_moh_classes(int reload)
 			ast_log(LOG_WARNING, "The old musiconhold.conf syntax has been deprecated!  Please refer to the sample configuration for information on the new syntax.\n");
 			dep_warning = 1;
 		}
-		if (!(get_mohbyname(var->name))) {
+		if (!(get_mohbyname(var->name, 0))) {
 			args = strchr(var->value, ',');
 			if (args)
 				*args++ = '\0';
 			class = moh_class_malloc();
 			if (!class) {
 				ast_log(LOG_WARNING, "Out of memory!\n");
-				return numclasses;
+				break;
 			}
 			
 			ast_copy_string(class->name, var->name, sizeof(class->name));
